==> humanize-duration-3.7.1.jar: META-INF/resources/webjars/humanize-duration/3.7.1/HISTORY.md <==
3.7.1 / 2016-04-26
==================

* fix: rounding had some more errors

3.7.0 / 2016-03-18
==================

* new: Vietnamese support

3.6.1 / 2016-02-19
==================

* update: readme should use single quotes

* fix: rounding had some errors (for example, you could get "1 day, 24 hours")
* fix: readme example was missing some quotes in its result

3.6.0 / 2016-02-12
==================

* new: Lithuanian support

* fix: add trailing semicolon to improve concatenation with other libraries

3.5.0 / 2016-01-13
==================

* new: Finnish support
* new: recommend [millisec](https://github.com/sungwoncho/millisec) module in readme

3.4.0 / 2015-12-11
==================

* new: Czech support

* update: minor performance improvements
* update: add "related modules" section to readme

* fix: add Greek to readme

3.3.0 / 2015-08-05
==================

* new: `unitMeasures` option

3.2.1 / 2015-07-22
==================

* fix: document `largest` option

3.2.0 / 2015-07-15
==================

* new: Ukrainian support

* fix: things would break in global strict mode

3.1.0 / 2015-06-25
==================

* new: Greek support

3.0.0 / 2015-05-29
==================

* new: `largest` option to get largest units

* update: languages can change decimal point (which can be overridden)
* update: fix some unintuitive `round` behavior
* update: specify units in shorthand rather than longhand
* update: use the Unlicense
* update: `nob` is now `no`
* update: use underscores instead of dashes for Chinese

* remove: half units

2.8.0 / 2015-05-10
==================

* new: `getSupportedLanguages`

2.7.0 / 2015-05-08
==================

* new: changelog
* new: Arabic support
* new: Italian support

* remove: (spoken) languages from package.json keywords

==> humanize-duration-3.10.0.jar: META-INF/resources/webjars/humanize-duration/3.10.0/HISTORY.md <==
3.10.0 / 2016-11-29
===================

* new: Icelandic support

3.9.1 / 2016-07-24
==================

* fix: Russian and Ukranian fixes

3.9.0 / 2016-06-10
==================

* new: Indonesian support
* new: Malay support

3.8.0 / 2016-05-19
==================

* new: `conjunctions` and `serialComma` options

* update: improve documentation

3.7.1 / 2016-04-26
==================

* fix: rounding had some more errors

3.7.0 / 2016-03-18
==================

* new: Vietnamese support

3.6.1 / 2016-02-19
==================

* update: readme should use single quotes

* fix: rounding had some errors (for example, you could get "1 day, 24 hours")
* fix: readme example was missing some quotes in its result

3.6.0 / 2016-02-12
==================

* new: Lithuanian support

* fix: add trailing semicolon to improve concatenation with other libraries

3.5.0 / 2016-01-13
==================

* new: Finnish support
* new: recommend [millisec](https://github.com/sungwoncho/millisec) module in readme

3.4.0 / 2015-12-11
==================

* new: Czech support

* update: minor performance improvements
* update: add "related modules" section to readme

* fix: add Greek to readme

3.3.0 / 2015-08-05
==================

* new: `unitMeasures` option

3.2.1 / 2015-07-22
==================

* fix: document `largest` option

3.2.0 / 2015-07-15
==================

* new: Ukrainian support

* fix: things would break in global strict mode

3.1.0 / 2015-06-25
==================

* new: Greek support

3.0.0 / 2015-05-29
==================

* new: `largest` option to get largest units

* update: languages can change decimal point (which can be overridden)
* update: fix some unintuitive `round` behavior
* update: specify units in shorthand rather than longhand
* update: use the Unlicense
* update: `nob` is now `no`
* update: use underscores instead of dashes for Chinese

* remove: half units

2.8.0 / 2015-05-10
==================

* new: `getSupportedLanguages`

2.7.0 / 2015-05-08
==================

* new: changelog
* new: Arabic support
* new: Italian support

* remove: (spoken) languages from package.json keywords
